@@ -171,71 +171,6 @@ class Page(Base):
                 )) \
                 .scalar()
 
-    @classmethod
-    def get_next_job(cls, db, look_ahead_pages, expiration, cache, lock_expiration, avg_links_per_page=10):
-        from holmes.models import Domain  # Avoid circular dependency
-
-        page = None
-        lock = None
-
-        expired_time = datetime.utcnow() - timedelta(seconds=expiration)
-
-        active_domains = Domain.get_active_domains(db)
-        active_domains_ids = [item.id for item in active_domains]
-        shuffle(active_domains_ids)
-
-        all_domains_pages_in_need_of_review = []
-
-        for domain_id in active_domains_ids:
-            pages = db \
-                .query(
-                    Page.uuid,
-                    Page.url,
-                    Page.score,
-                    Page.last_review_date
-                ) \
-                .filter(Page.domain_id == domain_id) \
-                .filter(or_(
-                    Page.last_review_date == None,
-                    Page.last_review_date <= expired_time
-                )) \
-                .order_by(Page.last_review_date.asc())[:look_ahead_pages]
-
-            if pages:
-                all_domains_pages_in_need_of_review.append(pages)
-
-        current_domain = 0
-        while page is None and len(all_domains_pages_in_need_of_review) > 0:
-            if current_domain >= len(all_domains_pages_in_need_of_review):
-                current_domain = 0
-
-            item = all_domains_pages_in_need_of_review[current_domain].pop(0)
-
-            # if there are not any more pages in this domain remove it from dictionary
-            if not all_domains_pages_in_need_of_review[current_domain]:
-                del all_domains_pages_in_need_of_review[current_domain]
-
-            lock = cache.has_next_job_lock(
-                item.url,
-                lock_expiration
-            )
-
-            if lock is not None:
-                page = item
-                break
-
-            current_domain += 1
-
-        if page is None:
-            return None
-
-        return {
-            'page': str(page.uuid),
-            'url': page.url,
-            'score': page.score,
-            'lock': lock
-        }
-
     @classmethod
     @return_future
     def add_page(cls, db, cache, url, score, fetch_method, publish_method, config, callback):
